@@ -33,9 +33,10 @@
 #  define KDECLARATIVE_DEPRECATED_NO_EXPORT KDECLARATIVE_NO_EXPORT KDECLARATIVE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KDECLARATIVE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KDECLARATIVE_NO_DEPRECATED
+#    define KDECLARATIVE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
